akhdefo_functions.MeanProducts_plot_ts — Akhdefo software documentation

# akhdefo_functions.MeanProducts_plot_ts

akhdefo_functions.MeanProducts_plot_ts(path_to_shapefile='', dem_path='', out_folder='Figs_analysis', color_field='', Set_fig_MinMax=False, MinMaxRange=[-100, 100], opacity=0.5, cmap='jet', point_size=1, cbar_label='mm/year')

  This program used to plot shapefile data

  ## Parameters

  path_to_shapefile : str

  dem_path : str

  out_folder : str

  color_fieldstr

    geopandas column name

  Set_fig_MinMax : bool

  MinMaxRange : list

  opacity : float

  cmap : str

  point_size : str

  cbar_labelstr

    “mm/year” or “degrees”, etc.. based on unit of the data column name in the color_field

  ## Returns

  Figure